View source: R/gen_params_evidence.R
| gen_params_evidence | R Documentation |
Generates predetermined parameters for testing the functionality of the graphical evidence method
gen_params_evidence(prior_name = c("Wishart", "BGL", "GHS", "G_Wishart"))
prior_name |
The name of the prior for being tested with preexisting test parameters, this is one of 'Wishart', 'BGL', 'GHS', 'G_Wishart' |
A list of matrices representing test parameters dependent on the prior specified in prior_name
# Generate test parameter matrices for G-Wishart prior
gen_params_evidence('G_Wishart')
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.