set_seed_evidence: Set the Random Seed

View source: R/set_seed_evidence.R

set_seed_evidenceR Documentation

Set the Random Seed

Description

Sets the random seed of both the R session (using set.seed) and the compiled sampler, as both samplers are used during any calls to evidence(...) or prior_sampling(...)

Usage

set_seed_evidence(seed)

Arguments

seed

a random seed that will be passed to the interpreted random number generator using set.seed, and will be passed to the compiled random number generator using private Rcpp package function set_seed

Value

No return value, this function is called to set the random seed.

Examples

set_seed_evidence(42)

graphicalEvidence documentation built on April 3, 2025, 6:05 p.m.