View source: R/set_seed_evidence.R
| set_seed_evidence | R Documentation |
Sets the random seed of both the R session (using set.seed) and the compiled sampler, as both samplers are used during any calls to evidence(...) or prior_sampling(...)
set_seed_evidence(seed)
seed |
a random seed that will be passed to the interpreted random number generator using set.seed, and will be passed to the compiled random number generator using private Rcpp package function set_seed |
No return value, this function is called to set the random seed.
set_seed_evidence(42)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.